pub struct Fault {
pub source: Option<Box<dyn StdError + Send + Sync>>,
/* private fields */
}Expand description
Wrapper for errors that should not happen but cannot panic. It is wrapped in the Error::Fault variant.
To generate it from predicates use Fault::new, from Result or Option import the prelude and use either or_fault(), or_fault_no_source(), or_fault_force(), or_fault_no_source_force(), ok_or_fault() ok_or_fault_force()
Fields
source: Option<Box<dyn StdError + Send + Sync>>Implementations
Sourceimpl Fault
impl Fault
Sourcepub fn with_source<E: StdError + 'static + Send + Sync>(self, error: E) -> Self
pub fn with_source<E: StdError + 'static + Send + Sync>(self, error: E) -> Self
Add an error source to a Fault. Usefull to generate a fault when pattern matching on an error type.
On a Result use map_err_or_fault to be more concise.
Examples
fn fetch() -> Result<()> {
let sqlx_error = sqlx::Error::RowNotFound;
Err(match sqlx_error {
sqlx::Error::RowNotFound => MyEntitysError::NotFound.into(),
_ => Fault::new().with_source(sqlx_error).into()
})
}Sourcepub fn with_context(self, context: impl Display) -> Self
pub fn with_context(self, context: impl Display) -> Self
Sourcepub fn backtrace_status(&self) -> BacktraceStatus
pub fn backtrace_status(&self) -> BacktraceStatus
Return the status of the backtrace